@@ -146,6 +146,13 @@ class PgDatabase:
         return _dict
 
     def _execute(self, sql_string, sql_params=None, get_result=True):
+        @staticmethod
+        def build_dict(cursor, row):
+            x = {}
+            for key, col in enumerate(cursor.description):
+                x[col[0]] = row[key]
+            return x
+
         err_str = f'Error in {self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         if not self.connect_to_db():
             return False
@@ -156,7 +163,11 @@ class PgDatabase:
             else:
                 cursor.execute(sql_string, self._update_dict(sql_params))
             if get_result:
-                self._result = cursor.fetchall() or []
+                result = cursor.fetchall() or []
+                if result and isinstance(result[0], tuple):
+                    self._result = list(map(lambda row: build_dict(cursor, row), result))
+                else:
+                    self._result = result
             return True
         except Exception as e:
             print(f'{err_str}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
